//#define XERR
#include "modbase.ih"

ModBase::ModBase(string const &id)
:
    d_base{ id + ':', "costs:" },
    d_id(id),
    d_value(s_nextValue),
    d_defined(Parser::hasSection(d_base))
{
    s_nextValue <<= 1;

    if (d_defined)
        Parser::nonNegative(d_base, d_cost);
    
}
